==> hisparc-sapphire-0.12.2.tar.gz: hisparc-sapphire-0.12.2/sapphire/tests/simulations/test_simulation_acceptance.py <==
import os
import unittest
import warnings

from sapphire.tests.validate_results import validate_results
from perform_simulation import (create_tempfile_path,
                                perform_groundparticlessimulation,
                                perform_flatfrontsimulation,
                                perform_nkgldfsimulation,
                                test_data_path, test_data_flat, test_data_nkg)


class GroundparticlesSimulationAcceptanceTest(unittest.TestCase):

    def setUp(self):
        warnings.filterwarnings('ignore')

    def tearDown(self):
        warnings.resetwarnings()

    def test_simulation_output(self):
        """Perform a simulation and verify the output"""

        output_path = create_tempfile_path()
        perform_groundparticlessimulation(output_path)
        validate_results(self, test_data_path, output_path)
        os.remove(output_path)


class FlatFrontSimulationAcceptanceTest(unittest.TestCase):

    def test_simulation_output(self):
        """Perform a simulation and verify the output"""

        output_path = create_tempfile_path()
        perform_flatfrontsimulation(output_path)
        validate_results(self, test_data_flat, output_path)
        os.remove(output_path)


class NkgLdfSimulationAcceptanceTest(unittest.TestCase):

    def setUp(self):
        warnings.filterwarnings('ignore')

    def tearDown(self):
        warnings.resetwarnings()

    def test_simulation_output(self):
        """Perform a simulation and verify the output"""

        output_path = create_tempfile_path()
        perform_nkgldfsimulation(output_path)
        validate_results(self, test_data_nkg, output_path)
        os.remove(output_path)


if __name__ == '__main__':
    unittest.main()

==> hisparc-sapphire-1.1.0.tar.gz: hisparc-sapphire-1.1.0/sapphire/tests/simulations/test_simulation_acceptance.py <==
import os
import unittest

from sapphire.tests.validate_results import validate_results
from perform_simulation import (create_tempfile_path,
                                perform_groundparticlessimulation,
                                perform_groundparticlesgammasimulation,
                                perform_flatfrontsimulation,
                                perform_nkgldfsimulation,
                                test_data_path, test_data_gamma, test_data_flat, test_data_nkg)


class GroundparticlesSimulationAcceptanceTest(unittest.TestCase):

    def test_simulation_output(self):
        """Perform a simulation and verify the output"""

        output_path = create_tempfile_path()
        perform_groundparticlessimulation(output_path)
        validate_results(self, test_data_path, output_path)
        os.remove(output_path)


class GroundparticlesGammaSimulationAcceptanceTest(unittest.TestCase):

    def test_simulation_output(self):
        """Perform a simulation and verify the output"""

        output_path = create_tempfile_path()
        perform_groundparticlesgammasimulation(output_path)
        validate_results(self, test_data_gamma, output_path)
        os.remove(output_path)


class FlatFrontSimulationAcceptanceTest(unittest.TestCase):

    def test_simulation_output(self):
        """Perform a simulation and verify the output"""

        output_path = create_tempfile_path()
        perform_flatfrontsimulation(output_path)
        validate_results(self, test_data_flat, output_path)
        os.remove(output_path)


class NkgLdfSimulationAcceptanceTest(unittest.TestCase):

    def test_simulation_output(self):
        """Perform a simulation and verify the output"""

        output_path = create_tempfile_path()
        perform_nkgldfsimulation(output_path)
        validate_results(self, test_data_nkg, output_path)
        os.remove(output_path)


if __name__ == '__main__':
    unittest.main()
